SystemOrganization addCategory: #ConfigurationOfSightTagging!

Object subclass: #ConfigurationOfSightTagging
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSightTagging'!

!ConfigurationOfSightTagging commentStamp: '<historical>' prior: 0!
Copy me to create a new configuration or edit and evaluate the following doits.

        "Create configuration class and initial baseline method"

        MetacelloToolBox 
                createBaseline: '1.0-baseline'
                for: 'MyProject'
                repository: 'http://www.example.com/MyProjectRepository'
                requiredProjects: #('Gofer')
                packages: #('MyProject-Core' 'MyProject-Tests')
                dependencies:
                        {('MyProject-Core' -> #('Gofer')).
                         ('MyProject-Tests' -> #('MyProject-Core'))}
                groups:
                        {('default' -> #('Core')).
                        ('Core' -> #('MyProject-Core')).
                        ('Tests' -> #('MyProject-Tests'))}.

	   "create initial development method from the baseline"

         MetacelloToolBox
               createDevelopment: '1.0'
               for: 'MyProject'
                importFromBaseline: '1.0-baseline'
                description: 'initial version'.
!

!ConfigurationOfSightTagging class methodsFor: 'development support' stamp: 'lt 8/1/2012 13:35:10.599'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSightTagging class methodsFor: 'private' stamp: 'lt 8/1/2012 13:35:10.614'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSightTagging class methodsFor: 'private' stamp: 'lt 8/1/2012 13:35:10.621'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSightTagging class methodsFor: 'private' stamp: 'mt 7/26/2013 08:49:41.92'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemtalksystems.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSightTagging class methodsFor: 'as yet unclassified' stamp: 'mt 7/19/2013 15:07:08.249'!
ensureRepositoryAccessFor: spec

	| privatePackages loginData |
	privatePackages := spec.
	loginData := Dictionary new.
		
	privatePackages keysAndValuesDo: [:packageName :location |
		| repository addDefault |
		addDefault := false.
		"Try to find the repository in the corresponding package."
		repository := (MCPackage named: packageName) workingCopy repositoryGroup in: [:group |
			group repositories
				detect: [:repo | repo description endsWith: location second]
				ifNone: []].
		"Try to find the repository in the default group."
		repository ifNil: [repository := (MCRepositoryGroup default repositories
			detect: [:repo | repo description endsWith: location second]
			ifNone: []) ifNotNil: [:r | addDefault := true. r]].
		
		"Create a new one if still not found."
		repository ifNil: [
			loginData at: location first ifAbsentPut: [
					(UIManager default request: 'User (', location first, ')')
						-> (UIManager default requestPassword: 'Password (', location first, ')')].
			repository := MCHttpRepository
					location: location first, location second
					user: (loginData at: location first) key
					password: (loginData at: location first) value.
			addDefault := true].
			
		addDefault ifTrue: [
			(MCPackage named: packageName) workingCopy repositoryGroup addRepository: repository]].! !

!ConfigurationOfSightTagging class methodsFor: 'metacello tool support' stamp: 'lt 8/1/2012 13:35:10.633'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSightTagging class methodsFor: 'loading' stamp: 'lt 8/1/2012 13:35:10.637'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSightTagging class methodsFor: 'loading' stamp: 'lt 8/1/2012 13:35:10.642'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSightTagging class methodsFor: 'loading' stamp: 'lt 8/1/2012 13:35:10.646'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSightTagging class methodsFor: 'loading' stamp: 'lt 8/2/2012 10:58:26.505'!
loadSnapshot
	"Load the latest snapshot which may be buggy but is not equivalent with the current head #development version."

	"self loadSnapshot"

	<apiDocumentation>
	^(self project version: #snapshot) load! !

!ConfigurationOfSightTagging class methodsFor: 'accessing' stamp: 'lt 8/1/2012 13:35:10.651'!
project

	^self new project! !

!ConfigurationOfSightTagging class methodsFor: 'development support' stamp: 'lt 8/1/2012 13:35:10.608'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSightTagging methodsFor: 'baselines' stamp: 'lt 8/1/2012 13:42:29.218'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/CodeSight'.

		spec 
			package: 'Sight-Tagging';
			group: 'default' with: #('Sight-Tagging')].! !

!ConfigurationOfSightTagging methodsFor: 'symbolic versions' stamp: 'mt 4/5/2013 14:58:05.49'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'common' version: '1.0'.! !

!ConfigurationOfSightTagging methodsFor: 'as yet unclassified' stamp: 'mt 7/19/2013 15:07:27.052'!
initialize

	super initialize.
	
	self class ensureRepositoryAccessFor: (Dictionary newFrom: {
		#'Sight-Tagging' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'CodeSight')}).! !

!ConfigurationOfSightTagging methodsFor: 'accessing' stamp: 'lt 8/1/2012 13:35:10.589'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSightTagging methodsFor: 'symbolic versions' stamp: 'mt 4/5/2013 14:57:58.279'!
snapshot: spec
	<symbolicVersion: #snapshot>
	
	spec for: #'common' version: '0.3'.! !

!ConfigurationOfSightTagging methodsFor: 'versions' stamp: 'lt 8/2/2012 10:58:02.523'!
version010: spec
	<version: '0.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Lauritz Thamsen'.
			
		spec
			package: 'Sight-Tagging' with: 'Sight-Tagging-lt.2'].! !

!ConfigurationOfSightTagging methodsFor: 'versions' stamp: 'mt 10/8/2012 10:34:57.066'!
version020: spec
	<version: '0.2' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
			
		spec
			package: 'Sight-Tagging' with: 'Sight-Tagging-mt.3'].! !

!ConfigurationOfSightTagging methodsFor: 'versions' stamp: 'mt 4/5/2013 14:57:54.536'!
version030: spec
	<version: '0.3' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
			
		spec
			package: 'Sight-Tagging' with: 'Sight-Tagging-mt.4'].! !

!ConfigurationOfSightTagging methodsFor: 'versions' stamp: 'mt 4/5/2013 14:57:30.459'!
version100: spec
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Marcel Taeumel'.
			
		spec package: 'Sight-Tagging'].! !
